@@ -610,7 +610,7 @@ write_VIEWS <- function(reposRootPath, fields = NULL,
 
         ## Use code from tools to build a matrix of package info
         pkg.dir <- file.path(reposRootPath, reposInfo[, os])
-        if(grepl(os, pattern="mac.binary")) os = "mac.binary"
+        if(grepl(os, pattern="mac.*.binary")) os = "mac.binary"
         if(grepl(os, pattern="win.binary")) os = "win.binary"
         db <- tools:::.build_repository_package_db(pkg.dir, fields, os, verbose)
         ## Turn 'db' into a matrix with 1 row per package
@@ -651,6 +651,7 @@ write_VIEWS <- function(reposRootPath, fields = NULL,
                           'source'=".tar.gz",
                           'win.binary'=".zip",
                           'mac.binary'=,
+                          'mac.binary.big-sur-arm64'=,
                           'mac.binary.mavericks'=,
                           'mac.binary.el-capitan'=".tgz",
                           stop("unknown type"))
